@@ -6,7 +6,11 @@ class UnknowItem(BaronError):
     pass
 
 
-KEYWORDS = ("and", "as", "assert", "break", "class", "continue", "def", "del", "elif", "else", "except", "exec", "finally", "for", "from", "global", "nonlocal", "if", "import", "in", "is", "lambda", "not", "or", "pass", "print", "raise", "return", "try", "while", "with", "yield")
+KEYWORDS = ("and", "as", "assert", "break", "class", "continue", "def", "del",
+            "elif", "else", "except", "exec", "finally", "for", "from",
+            "global", "nonlocal", "if", "import", "in", "is", "lambda", "not",
+            "or", "pass", "print", "raise", "return", "try", "while", "with",
+            "yield")
 
 TOKENS = (
     (r'[a-zA-Z_]\w*', 'NAME'),
@@ -102,7 +106,7 @@ def tokenize(sequence, print_function=False):
 
 def tokenize_current_keywords(print_function=False):
     if print_function is True:
-        return [x for x in KEYWORDS if x != "print"]
+        return [x for x in KEYWORDS if x not in ("print", "exec")]
     else:
         return KEYWORDS
 
